@@ -7,9 +7,11 @@ from http.client import HTTPException
 from sentry_sdk import capture_exception
 
 
-class CustomHttpRequest:
-    def __init__(self, url, timeout = 60.0, *args, **kwargs):
+class CustomAsyncClient:
+    def __init__(self, url, method = "GET", data = None, timeout = 60.0, *args, **kwargs):
         self.url = url
+        self.method = method
+        self.data = data
         self.timeout = timeout
         self.client = self.get_client(*args, **kwargs)
 
@@ -25,7 +27,10 @@ class CustomHttpRequest:
     async def request_url(self) -> Response:
         async with self.client as client:
             try:
-                res = await client.get(url=self.url)
+                if self.data:
+                    res = await client.request(method=self.method, url=self.url, data=self.data)
+                else:
+                    res = await client.request(method=self.method, url=self.url)
                 res.raise_for_status()
 
             except HTTPError as e:
