@@ -13,7 +13,7 @@ def init_sentry(sentry_integrations: list, traces_sample_rate: float, sample_rat
     :param sentry_integrations:
     :param traces_sample_rate:
     :param sample_rate:
-    :return:
+    :return: sentry init function
     """
     return init(
         integrations=sentry_integrations,
